==> fetch.php?media=download:vbfnlo-0.9.tar.gz: vbfnlo-v.0.9/src/phasespace.f <==
c*************************************************************************
      SUBROUTINE phasespace(rand,
     &                      p, x,
     &                      v,   
     &                      dps  )
c*************************************************************************
c     This is the manager of all phasespace generators and the (only) 
c     interface of those to the main program.  Depending on the process ID
c     the right phasespace generator is called with the correct calling 
c     convention, which might well be individually different.
c
c
c     Currently there is only the phasespace generator of Manuels single top 
c     production in here.
c*************************************************************************
c     INPUT
c     rand            : Array with random numbers driven by monaco. 
c     p         : 4-momenta of the partons involved in the basic QCD 2->2(+1)+X process.
c                       The first 2 entries are the incoming partons.
c     x               : the feynman x of the incoming partons 
c     v : The 4-momenta of the other particles
c     
c     OUTPUT
c     dps             : The jacobi factor of the phasespace point.
c*************************************************************************
      implicit none
      
      include 'global.inc'

      real*8 x(nx) 
      real*8 rand(max_PS_dim)
      real*8 p(0:3,max_p,max_ptilde)
      real*8 v(0:3,max_v,max_vtilde)
      real*8 dps, dps_dec

      real*8 rn
      real*8 Q(0:4), QV(0:4,2)
      integer i,L,mu
   
      real*8 RandomNumber
      external RandomNumber

c fill momentum arrays with zero
      do L=1,3
         do i = 1,max_p
            do mu=0,3
               p(mu,i,L) = 0d0
            enddo
         enddo
      enddo
      do i=1,max_v
         do mu=0,3
            v(mu,i,1) = 0d0
         enddo
      enddo

c get additional random number not driven by VEGAS    
      rn = RandomNumber()
c switch between different processes

      SELECT CASE(procID)
      CASE(100:104,2100:2104) ! pp-> Hjj(j) -> xxjj(j)
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)
      CASE(111:119,141:147,2111:2119,2141:2147) ! pp -> Hjj(j) -> VVjj(j)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)
      CASE(201:204,301:306,2201:2204,2301:2306) ! pp -> Vjj(j) -> lljj(j)
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)
      CASE(411:419,2411:2419,501:507,2501:2507) ! pp -> VVjj(j)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)

cc      CASE(4100) ! pp -> Hjj in GF 
cc         call LIPSN0(n_p-nx, rand, rn,
cc     1               p(0,1,1), p(0,2,1), 
cc     2               Q, p(0,3,1), X(1), X(2), dps)
cc         v(0,1,1) = Q(0)
cc         v(1,1,1) = Q(1)
cc         v(2,1,1) = Q(2)
cc        v(3,1,1) = Q(3)   
cc      CASE(4101:4103,4201:4204)       
      CASE(4201:4204)       
cc         call LIPSN(n_p-nx, rand, rn,
cc    1              p(0,1,1), p(0,2,1), 
cc     2              Q, v(0,1,1), v(0,2,1),
cc     3              p(0,3,1), X(1), X(2), dps)  
cc      CASE(4111:4119,4411:4419)           
      CASE(4411:4419)           
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)
cc      CASE(9414)
cc         call lipstopW(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),
cc     &                     v(0,1,1),x(1),x(2),dps)  
cc      CASE(9415)
cc         call lipstopdecay(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),
cc     &        v(0,1,1),x(1),x(2),dps)   
      END SELECT

      RETURN
      END

==> fetch.php?media=download:vbfnlo-1.1.tar.gz: vbfnlo-v.1.1/src/phasespace.f <==
c*************************************************************************
      SUBROUTINE phasespace(rand,
     &                      p, x,
     &                      v,   
     &                      dps  )
c*************************************************************************
c     This is the manager of all phasespace generators and the (only) 
c     interface of those to the main program.  Depending on the process ID
c     the right phasespace generator is called with the correct calling 
c     convention, which might well be individually different.
c
c
c     Currently there is only the phasespace generator of Manuels single top 
c     production in here.
c*************************************************************************
c     INPUT
c     rand            : Array with random numbers driven by monaco. 
c     p         : 4-momenta of the partons involved in the basic QCD 2->2(+1)+X process.
c                       The first 2 entries are the incoming partons.
c     x               : the feynman x of the incoming partons 
c     v : The 4-momenta of the other particles
c     
c     OUTPUT
c     dps             : The jacobi factor of the phasespace point.
c*************************************************************************
      implicit none
      
      include 'global.inc'

      real*8 x(nx) 
      real*8 rand(max_PS_dim)
      real*8 p(0:3,max_p,max_ptilde)
      real*8 v(0:3,max_v,max_vtilde)
      real*8 dps, dps_dec

      real*8 rn
      real*8 Q(0:4), QV(0:4,2)
      integer i,L,mu
   
      real*8 RandomNumber
      external RandomNumber

c fill momentum arrays with zero
      do L=1,3
         do i = 1,max_p
            do mu=0,3
               p(mu,i,L) = 0d0
            enddo
         enddo
      enddo
      do i=1,max_v
         do mu=0,3
            v(mu,i,1) = 0d0
         enddo
      enddo

c get additional random number not driven by VEGAS    
      rn = RandomNumber()
c switch between different processes

      SELECT CASE(procID)
      CASE(100:104,2100:2104) ! pp-> Hjj(j) -> xxjj(j)
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)
      CASE(111:119,141:147,2111:2119,2141:2147) ! pp -> Hjj(j) -> VVjj(j)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)
      CASE(201:204,301:306,2201:2204,2301:2306) ! pp -> Vjj(j) -> lljj(j)
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)
      CASE(411:419,2411:2419,501:507,2501:2507) ! pp -> VVjj(j)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)

      CASE(4100) ! pp -> Hjj in GF 
         call LIPSN0(n_p-nx, rand, rn,
     1               p(0,1,1), p(0,2,1), 
     2               Q, p(0,3,1), X(1), X(2), dps)
         v(0,1,1) = Q(0)
         v(1,1,1) = Q(1)
         v(2,1,1) = Q(2)
         v(3,1,1) = Q(3)   
      CASE(4101:4103,4201:4204)          
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)  
      CASE(4111:4119,4411:4419)           
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)
      CASE(9414)
         call lipstopW(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),
     &                     v(0,1,1),x(1),x(2),dps)  
      CASE(9415)
         call lipstopdecay(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),
     &        v(0,1,1),x(1),x(2),dps)   
      END SELECT


!!!!!!!!!!!!!!!!!
c the old processes
      SELECT CASE(procID)
      CASE(1:8)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)
         
      CASE(10)
         call lipstopdecay(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),
     &        v(0,1,1),x(1),x(2),dps)

      CASE(11)
         call lipstopW(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),
     &                     v(0,1,1),x(1),x(2),dps)

      CASE(12)
         call LIPSN0(n_p-nx, rand, rn,
     1               p(0,1,1), p(0,2,1), 
     2               Q, p(0,3,1), X(1), X(2), dps)
         v(0,1,1) = Q(0)
         v(1,1,1) = Q(1)
         v(2,1,1) = Q(2)
         v(3,1,1) = Q(3)
      CASE(13,14)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)
      CASE(9,15:19,22:25)
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)
      CASE(20)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)

      CASE(21)
         call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)  

      CASE(0815)
         call lipstop(rand,rn,p(0,1,1),p(0,2,1),p(0,3,1),x(1),x(2),dps)
         

      CASE(50,51,54,55,56)
          call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)

      CASE(52,53)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)

      CASE(60,61,64,65,66)
          call LIPSN(n_p-nx, rand, rn,
     1              p(0,1,1), p(0,2,1), 
     2              Q, v(0,1,1), v(0,2,1),
     3              p(0,3,1), X(1), X(2), dps)

      CASE(62,63)
         call LIPSNVV(n_p-nx,rand,rn,
     1                p(0,1,1),p(0,2,1),
     2                v(0,1,1),p(0,3,1),
     3                X(1),X(2),dps)

      END SELECT

       

      RETURN
      END
